linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* [PATCH 2/3] block: Rename trace_block_remap to trace_block_bio_remap
@ 2009-09-18 15:13 Jun'ichi Nomura
  2009-09-18 16:13 ` Daniel Walker
  2009-09-19 15:30 ` Jun'ichi Nomura
  0 siblings, 2 replies; 7+ messages in thread
From: Jun'ichi Nomura @ 2009-09-18 15:13 UTC (permalink / raw)
  To: Jens Axboe, Alasdair G Kergon, Li Zefan
  Cc: linux-kernel, device-mapper development, j-nomura

Rename "block_remap" tracepoint to "block_bio_remap" to clarify the event.
No functional change.

Signed-off-by: Kiyoshi Ueda <k-ueda@ct.jp.nec.com>
Signed-off-by: Jun'ichi Nomura <j-nomura@ce.jp.nec.com>
Cc: Jens Axboe <jens.axboe@oracle.com>
Cc: Alasdair G Kergon <agk@redhat.com>
Cc: Li Zefan <lizf@cn.fujitsu.com>
---
 block/blk-core.c             |   10 +++++-----
 drivers/md/dm.c              |    4 ++--
 include/trace/events/block.h |    2 +-
 kernel/trace/blktrace.c      |   10 +++++-----
 4 files changed, 13 insertions(+), 13 deletions(-)

Index: linux-2.6.31.work/include/trace/events/block.h
===================================================================
--- linux-2.6.31.work.orig/include/trace/events/block.h
+++ linux-2.6.31.work/include/trace/events/block.h
@@ -453,7 +453,7 @@ TRACE_EVENT(block_split,
 		  __entry->comm)
 );

-TRACE_EVENT(block_remap,
+TRACE_EVENT(block_bio_remap,

 	TP_PROTO(struct request_queue *q, struct bio *bio, dev_t dev,
 		 sector_t from),
Index: linux-2.6.31.work/block/blk-core.c
===================================================================
--- linux-2.6.31.work.orig/block/blk-core.c
+++ linux-2.6.31.work/block/blk-core.c
@@ -33,7 +33,7 @@

 #include "blk.h"

-EXPORT_TRACEPOINT_SYMBOL_GPL(block_remap);
+EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_rq_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_complete);

@@ -1285,9 +1285,9 @@ static inline void blk_partition_remap(s
 		bio->bi_sector += p->start_sect;
 		bio->bi_bdev = bdev->bd_contains;

-		trace_block_remap(bdev_get_queue(bio->bi_bdev), bio,
-				    bdev->bd_dev,
-				    bio->bi_sector - p->start_sect);
+		trace_block_bio_remap(bdev_get_queue(bio->bi_bdev), bio,
+				      bdev->bd_dev,
+				      bio->bi_sector - p->start_sect);
 	}
 }

@@ -1455,7 +1455,7 @@ static inline void __generic_make_reques
 			goto end_io;

 		if (old_sector != -1)
-			trace_block_remap(q, bio, old_dev, old_sector);
+			trace_block_bio_remap(q, bio, old_dev, old_sector);

 		trace_block_bio_queue(q, bio);

Index: linux-2.6.31.work/drivers/md/dm.c
===================================================================
--- linux-2.6.31.work.orig/drivers/md/dm.c
+++ linux-2.6.31.work/drivers/md/dm.c
@@ -961,8 +961,8 @@ static void __map_bio(struct dm_target *
 	if (r == DM_MAPIO_REMAPPED) {
 		/* the bio has been remapped so dispatch it */

-		trace_block_remap(bdev_get_queue(clone->bi_bdev), clone,
-				    tio->io->bio->bi_bdev->bd_dev, sector);
+		trace_block_bio_remap(bdev_get_queue(clone->bi_bdev), clone,
+				      tio->io->bio->bi_bdev->bd_dev, sector);

 		generic_make_request(clone);
 	} else if (r < 0 || r == DM_MAPIO_REQUEUE) {

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH 2/3] block: Rename trace_block_remap to trace_block_bio_remap
  2009-09-18 15:13 [PATCH 2/3] block: Rename trace_block_remap to trace_block_bio_remap Jun'ichi Nomura
@ 2009-09-18 16:13 ` Daniel Walker
  2009-09-19 15:30 ` Jun'ichi Nomura
  1 sibling, 0 replies; 7+ messages in thread
From: Daniel Walker @ 2009-09-18 16:13 UTC (permalink / raw)
  To: Jun'ichi Nomura
  Cc: Jens Axboe, Alasdair G Kergon, Li Zefan, linux-kernel,
	device-mapper development

On Sat, 2009-09-19 at 00:13 +0900, Jun'ichi Nomura wrote:
>   **/
> -static void blk_add_trace_remap(struct request_queue *q, struct bio *bio,
> -                                      dev_t dev, sector_t from)
> +static void blk_add_trace_bio_remap(struct request_queue *q, struct bio
> *bio,
> +                                   dev_t dev, sector_t from)
>  {

You might need to resubmit this, you have some line wrapping in the
above lines.. Your should be able to set the patch part of the email to
"preformatted" , you don't want your mailer line wrapping .. (even
better just use git-format-patch and git-send-email) ..

Daniel


^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH 2/3] block: Rename trace_block_remap to trace_block_bio_remap
  2009-09-18 15:13 [PATCH 2/3] block: Rename trace_block_remap to trace_block_bio_remap Jun'ichi Nomura
  2009-09-18 16:13 ` Daniel Walker
@ 2009-09-19 15:30 ` Jun'ichi Nomura
  2010-11-03 21:50   ` [PATCH v2] block: rename " Mike Snitzer
  1 sibling, 1 reply; 7+ messages in thread
From: Jun'ichi Nomura @ 2009-09-19 15:30 UTC (permalink / raw)
  To: Jens Axboe, Alasdair G Kergon, Li Zefan
  Cc: linux-kernel, device-mapper development

Sorry, the previous mail has line-wrapped.
Re-sending the patch.

Rename "block_remap" tracepoint to "block_bio_remap" to clarify the event.
No functional change.

Signed-off-by: Kiyoshi Ueda <k-ueda@ct.jp.nec.com>
Signed-off-by: Jun'ichi Nomura <j-nomura@ce.jp.nec.com>
Cc: Jens Axboe <jens.axboe@oracle.com>
Cc: Alasdair G Kergon <agk@redhat.com>
Cc: Li Zefan <lizf@cn.fujitsu.com>
---
 block/blk-core.c             |   10 +++++-----
 drivers/md/dm.c              |    4 ++--
 include/trace/events/block.h |    2 +-
 kernel/trace/blktrace.c      |   10 +++++-----
 4 files changed, 13 insertions(+), 13 deletions(-)

Index: linux-2.6.31.work/include/trace/events/block.h
===================================================================
--- linux-2.6.31.work.orig/include/trace/events/block.h
+++ linux-2.6.31.work/include/trace/events/block.h
@@ -453,7 +453,7 @@ TRACE_EVENT(block_split,
 		  __entry->comm)
 );

-TRACE_EVENT(block_remap,
+TRACE_EVENT(block_bio_remap,

 	TP_PROTO(struct request_queue *q, struct bio *bio, dev_t dev,
 		 sector_t from),
Index: linux-2.6.31.work/block/blk-core.c
===================================================================
--- linux-2.6.31.work.orig/block/blk-core.c
+++ linux-2.6.31.work/block/blk-core.c
@@ -33,7 +33,7 @@

 #include "blk.h"

-EXPORT_TRACEPOINT_SYMBOL_GPL(block_remap);
+EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_rq_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_complete);

@@ -1285,9 +1285,9 @@ static inline void blk_partition_remap(s
 		bio->bi_sector += p->start_sect;
 		bio->bi_bdev = bdev->bd_contains;

-		trace_block_remap(bdev_get_queue(bio->bi_bdev), bio,
-				    bdev->bd_dev,
-				    bio->bi_sector - p->start_sect);
+		trace_block_bio_remap(bdev_get_queue(bio->bi_bdev), bio,
+				      bdev->bd_dev,
+				      bio->bi_sector - p->start_sect);
 	}
 }

@@ -1455,7 +1455,7 @@ static inline void __generic_make_reques
 			goto end_io;

 		if (old_sector != -1)
-			trace_block_remap(q, bio, old_dev, old_sector);
+			trace_block_bio_remap(q, bio, old_dev, old_sector);

 		trace_block_bio_queue(q, bio);

Index: linux-2.6.31.work/drivers/md/dm.c
===================================================================
--- linux-2.6.31.work.orig/drivers/md/dm.c
+++ linux-2.6.31.work/drivers/md/dm.c
@@ -961,8 +961,8 @@ static void __map_bio(struct dm_target *
 	if (r == DM_MAPIO_REMAPPED) {
 		/* the bio has been remapped so dispatch it */

-		trace_block_remap(bdev_get_queue(clone->bi_bdev), clone,
-				    tio->io->bio->bi_bdev->bd_dev, sector);
+		trace_block_bio_remap(bdev_get_queue(clone->bi_bdev), clone,
+				      tio->io->bio->bi_bdev->bd_dev, sector);

 		generic_make_request(clone);
 	} else if (r < 0 || r == DM_MAPIO_REQUEUE) {


^ permalink raw reply	[flat|nested] 7+ messages in thread

* [PATCH v2] block: rename trace_block_remap to trace_block_bio_remap
  2009-09-19 15:30 ` Jun'ichi Nomura
@ 2010-11-03 21:50   ` Mike Snitzer
  2010-11-15 20:58     ` Mike Snitzer
  0 siblings, 1 reply; 7+ messages in thread
From: Mike Snitzer @ 2010-11-03 21:50 UTC (permalink / raw)
  To: Jun'ichi Nomura, jaxboe
  Cc: device-mapper development, Alasdair G Kergon, Li Zefan, linux-kernel

Rename "block_remap" tracepoint to "block_bio_remap" to clarify the
event.

Signed-off-by: Kiyoshi Ueda <k-ueda@ct.jp.nec.com>
Signed-off-by: Jun'ichi Nomura <j-nomura@ce.jp.nec.com>
Signed-off-by: Mike Snitzer <snitzer@redhat.com>
---
 block/blk-core.c             |   10 +++++-----
 drivers/md/dm.c              |    4 ++--
 include/trace/events/block.h |    6 +++---
 kernel/trace/blktrace.c      |   12 ++++++------
 4 files changed, 16 insertions(+), 16 deletions(-)

v2: patch needed to be rebased and it should go through the Jens'
linux-2.6-block tree.  The original v1 patch is here:
https://patchwork.kernel.org/patch/48763/

diff --git a/block/blk-core.c b/block/blk-core.c
index f0834e2..9d5a61f 100644
--- a/block/blk-core.c
+++ b/block/blk-core.c
@@ -33,7 +33,7 @@
 
 #include "blk.h"
 
-EXPORT_TRACEPOINT_SYMBOL_GPL(block_remap);
+EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_rq_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_complete);
 
@@ -1336,9 +1336,9 @@ static inline void blk_partition_remap(struct bio *bio)
 		bio->bi_sector += p->start_sect;
 		bio->bi_bdev = bdev->bd_contains;
 
-		trace_block_remap(bdev_get_queue(bio->bi_bdev), bio,
-				    bdev->bd_dev,
-				    bio->bi_sector - p->start_sect);
+		trace_block_bio_remap(bdev_get_queue(bio->bi_bdev), bio,
+				      bdev->bd_dev,
+				      bio->bi_sector - p->start_sect);
 	}
 }
 
@@ -1507,7 +1507,7 @@ static inline void __generic_make_request(struct bio *bio)
 			goto end_io;
 
 		if (old_sector != -1)
-			trace_block_remap(q, bio, old_dev, old_sector);
+			trace_block_bio_remap(q, bio, old_dev, old_sector);
 
 		old_sector = bio->bi_sector;
 		old_dev = bio->bi_bdev->bd_dev;
diff --git a/drivers/md/dm.c b/drivers/md/dm.c
index 7cb1352..0a2b551 100644
--- a/drivers/md/dm.c
+++ b/drivers/md/dm.c
@@ -990,8 +990,8 @@ static void __map_bio(struct dm_target *ti, struct bio *clone,
 	if (r == DM_MAPIO_REMAPPED) {
 		/* the bio has been remapped so dispatch it */
 
-		trace_block_remap(bdev_get_queue(clone->bi_bdev), clone,
-				    tio->io->bio->bi_bdev->bd_dev, sector);
+		trace_block_bio_remap(bdev_get_queue(clone->bi_bdev), clone,
+				      tio->io->bio->bi_bdev->bd_dev, sector);
 
 		generic_make_request(clone);
 	} else if (r < 0 || r == DM_MAPIO_REQUEUE) {
Index: linux-2.6.31.work/kernel/trace/blktrace.c
===================================================================
--- linux-2.6.31.work.orig/kernel/trace/blktrace.c
+++ linux-2.6.31.work/kernel/trace/blktrace.c
@@ -822,7 +822,7 @@ static void blk_add_trace_split(struct r
 }

 /**
  * blk_add_trace_remap - Add a trace for a remap operation
  * @q:		queue the io is for
  * @bio:	the source bio
  * @dev:	target device
@@ -833,8 +833,8 @@ static void blk_add_trace_split(struct r
  *     it spans a stripe (or similar). Add a trace for that action.
  *
  **/
-static void blk_add_trace_remap(struct request_queue *q, struct bio *bio,
-				       dev_t dev, sector_t from)
+static void blk_add_trace_bio_remap(struct request_queue *q, struct bio
*bio,
+				    dev_t dev, sector_t from)
 {
 	struct blk_trace *bt = q->blk_trace;
 	struct blk_io_trace_remap r;
@@ -947,7 +947,7 @@ static void blk_register_tracepoints(voi
 	WARN_ON(ret);
 	ret = register_trace_block_split(blk_add_trace_split);
 	WARN_ON(ret);
-	ret = register_trace_block_remap(blk_add_trace_remap);
+	ret = register_trace_block_bio_remap(blk_add_trace_bio_remap);
 	WARN_ON(ret);
 	ret = register_trace_block_rq_remap(blk_add_trace_rq_remap);
 	WARN_ON(ret);
@@ -956,7 +956,7 @@ static void blk_register_tracepoints(voi
 static void blk_unregister_tracepoints(void)
 {
 	unregister_trace_block_rq_remap(blk_add_trace_rq_remap);
-	unregister_trace_block_remap(blk_add_trace_remap);
+	unregister_trace_block_bio_remap(blk_add_trace_bio_remap);
 	unregister_trace_block_split(blk_add_trace_split);
 	unregister_trace_block_unplug_io(blk_add_trace_unplug_io);
 	unregister_trace_block_unplug_timer(blk_add_trace_unplug_timer);
@@ -822,7 +822,7 @@ static void blk_add_trace_split(struct r

 /**
- * blk_add_trace_remap - Add a trace for a remap operation
+ * blk_add_trace_bio_remap - Add a trace for a bio-remap operation
  * @q:		queue the io is for
  * @bio:	the source bio
Index: linux-2.6.31.work/kernel/trace/blktrace.c
===================================================================
--- linux-2.6.31.work.orig/kernel/trace/blktrace.c
+++ linux-2.6.31.work/kernel/trace/blktrace.c
@@ -822,7 +822,7 @@ static void blk_add_trace_split(struct r
 }

 /**
  * blk_add_trace_remap - Add a trace for a remap operation
  * @q:		queue the io is for
  * @bio:	the source bio
  * @dev:	target device
@@ -833,8 +833,8 @@ static void blk_add_trace_split(struct r
  *     it spans a stripe (or similar). Add a trace for that action.
  *
  **/
-static void blk_add_trace_remap(struct request_queue *q, struct bio *bio,
-				       dev_t dev, sector_t from)
+static void blk_add_trace_bio_remap(struct request_queue *q, struct bio *bio,
+				    dev_t dev, sector_t from)
 {
 	struct blk_trace *bt = q->blk_trace;
 	struct blk_io_trace_remap r;
@@ -947,7 +947,7 @@ static void blk_register_tracepoints(voi
 	WARN_ON(ret);
 	ret = register_trace_block_split(blk_add_trace_split);
 	WARN_ON(ret);
-	ret = register_trace_block_remap(blk_add_trace_remap);
+	ret = register_trace_block_bio_remap(blk_add_trace_bio_remap);
 	WARN_ON(ret);
 	ret = register_trace_block_rq_remap(blk_add_trace_rq_remap);
 	WARN_ON(ret);
@@ -956,7 +956,7 @@ static void blk_register_tracepoints(voi
 static void blk_unregister_tracepoints(void)
 {
 	unregister_trace_block_rq_remap(blk_add_trace_rq_remap);
-	unregister_trace_block_remap(blk_add_trace_remap);
+	unregister_trace_block_bio_remap(blk_add_trace_bio_remap);
 	unregister_trace_block_split(blk_add_trace_split);
 	unregister_trace_block_unplug_io(blk_add_trace_unplug_io);
 	unregister_trace_block_unplug_timer(blk_add_trace_unplug_timer);
@@ -822,7 +822,7 @@ static void blk_add_trace_split(struct r

 /**
- * blk_add_trace_remap - Add a trace for a remap operation
+ * blk_add_trace_bio_remap - Add a trace for a bio-remap operation
  * @q:		queue the io is for
  * @bio:	the source bio
diff --git a/include/trace/events/block.h b/include/trace/events/block.h
index d8ce278..b56c65d 100644
--- a/include/trace/events/block.h
+++ b/include/trace/events/block.h
@@ -486,16 +486,16 @@ TRACE_EVENT(block_split,
 );
 
 /**
  * block_remap - map request for a partition to the raw device
  * @q: queue holding the operation
  * @bio: revised operation
  * @dev: device for the operation
  * @from: original sector for the operation
  *
- * An operation for a partition on a block device has been mapped to the
+ * An operation for a logical device has been mapped to the
  * raw block device.
  */
-TRACE_EVENT(block_remap,
+TRACE_EVENT(block_bio_remap,
 
 	TP_PROTO(struct request_queue *q, struct bio *bio, dev_t dev,
 		 sector_t from),
@@ -486,16 +486,16 @@ TRACE_EVENT(block_split,
 
 /**
- * block_remap - map request for a partition to the raw device
+ * block_bio_remap - map request for a logical device to the raw device
  * @q: queue holding the operation
  * @bio: revised operation
diff --git a/kernel/trace/blktrace.c b/kernel/trace/blktrace.c
index bc251ed..9f42529 100644
--- a/kernel/trace/blktrace.c
+++ b/kernel/trace/blktrace.c
@@ -889,7 +889,7 @@ static void blk_add_trace_split(void *ignore,
 }
 
 /**
  * blk_add_trace_remap - Add a trace for a remap operation
  * @ignore:	trace callback data parameter (not used)
  * @q:		queue the io is for
  * @bio:	the source bio
@@ -901,9 +901,9 @@ static void blk_add_trace_split(void *ignore,
  *     it spans a stripe (or similar). Add a trace for that action.
  *
  **/
-static void blk_add_trace_remap(void *ignore,
-				struct request_queue *q, struct bio *bio,
-				dev_t dev, sector_t from)
+static void blk_add_trace_bio_remap(void *ignore,
+				    struct request_queue *q, struct bio *bio,
+				    dev_t dev, sector_t from)
 {
 	struct blk_trace *bt = q->blk_trace;
 	struct blk_io_trace_remap r;
@@ -1018,7 +1018,7 @@ static void blk_register_tracepoints(void)
 	WARN_ON(ret);
 	ret = register_trace_block_split(blk_add_trace_split, NULL);
 	WARN_ON(ret);
-	ret = register_trace_block_remap(blk_add_trace_remap, NULL);
+	ret = register_trace_block_bio_remap(blk_add_trace_bio_remap, NULL);
 	WARN_ON(ret);
 	ret = register_trace_block_rq_remap(blk_add_trace_rq_remap, NULL);
 	WARN_ON(ret);
@@ -1027,7 +1027,7 @@ static void blk_register_tracepoints(void)
 static void blk_unregister_tracepoints(void)
 {
 	unregister_trace_block_rq_remap(blk_add_trace_rq_remap, NULL);
-	unregister_trace_block_remap(blk_add_trace_remap, NULL);
+	unregister_trace_block_bio_remap(blk_add_trace_bio_remap, NULL);
 	unregister_trace_block_split(blk_add_trace_split, NULL);
 	unregister_trace_block_unplug_io(blk_add_trace_unplug_io, NULL);
 	unregister_trace_block_unplug_timer(blk_add_trace_unplug_timer, NULL);

^ permalink raw reply related	[flat|nested] 7+ messages in thread

* Re: [PATCH v2] block: rename trace_block_remap to trace_block_bio_remap
  2010-11-03 21:50   ` [PATCH v2] block: rename " Mike Snitzer
@ 2010-11-15 20:58     ` Mike Snitzer
  2010-11-15 21:34       ` Mike Snitzer
  0 siblings, 1 reply; 7+ messages in thread
From: Mike Snitzer @ 2010-11-15 20:58 UTC (permalink / raw)
  To: jaxboe
  Cc: device-mapper development, Jun'ichi Nomura,
	Alasdair G Kergon, Li Zefan, linux-kernel

Hi Jens,

This may have slipped through while you were traveling?

Patch is also available here:
https://patchwork.kernel.org/patch/300552/

Not sure if this change is concerning on a kABI level?

Please advise, thanks.
Mike

On Wed, Nov 03 2010 at  5:50pm -0400,
Mike Snitzer <snitzer@redhat.com> wrote:

> Rename "block_remap" tracepoint to "block_bio_remap" to clarify the
> event.
> 
> Signed-off-by: Kiyoshi Ueda <k-ueda@ct.jp.nec.com>
> Signed-off-by: Jun'ichi Nomura <j-nomura@ce.jp.nec.com>
> Signed-off-by: Mike Snitzer <snitzer@redhat.com>
> ---
>  block/blk-core.c             |   10 +++++-----
>  drivers/md/dm.c              |    4 ++--
>  include/trace/events/block.h |    6 +++---
>  kernel/trace/blktrace.c      |   12 ++++++------
>  4 files changed, 16 insertions(+), 16 deletions(-)
> 
> v2: patch needed to be rebased and it should go through the Jens'
> linux-2.6-block tree.  The original v1 patch is here:
> https://patchwork.kernel.org/patch/48763/
> 
> diff --git a/block/blk-core.c b/block/blk-core.c
> index f0834e2..9d5a61f 100644
> --- a/block/blk-core.c
> +++ b/block/blk-core.c
> @@ -33,7 +33,7 @@
>  
>  #include "blk.h"
>  
> -EXPORT_TRACEPOINT_SYMBOL_GPL(block_remap);
> +EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_remap);
>  EXPORT_TRACEPOINT_SYMBOL_GPL(block_rq_remap);
>  EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_complete);
>  
> @@ -1336,9 +1336,9 @@ static inline void blk_partition_remap(struct bio *bio)
>  		bio->bi_sector += p->start_sect;
>  		bio->bi_bdev = bdev->bd_contains;
>  
> -		trace_block_remap(bdev_get_queue(bio->bi_bdev), bio,
> -				    bdev->bd_dev,
> -				    bio->bi_sector - p->start_sect);
> +		trace_block_bio_remap(bdev_get_queue(bio->bi_bdev), bio,
> +				      bdev->bd_dev,
> +				      bio->bi_sector - p->start_sect);
>  	}
>  }
>  
> @@ -1507,7 +1507,7 @@ static inline void __generic_make_request(struct bio *bio)
>  			goto end_io;
>  
>  		if (old_sector != -1)
> -			trace_block_remap(q, bio, old_dev, old_sector);
> +			trace_block_bio_remap(q, bio, old_dev, old_sector);
>  
>  		old_sector = bio->bi_sector;
>  		old_dev = bio->bi_bdev->bd_dev;
> diff --git a/drivers/md/dm.c b/drivers/md/dm.c
> index 7cb1352..0a2b551 100644
> --- a/drivers/md/dm.c
> +++ b/drivers/md/dm.c
> @@ -990,8 +990,8 @@ static void __map_bio(struct dm_target *ti, struct bio *clone,
>  	if (r == DM_MAPIO_REMAPPED) {
>  		/* the bio has been remapped so dispatch it */
>  
> -		trace_block_remap(bdev_get_queue(clone->bi_bdev), clone,
> -				    tio->io->bio->bi_bdev->bd_dev, sector);
> +		trace_block_bio_remap(bdev_get_queue(clone->bi_bdev), clone,
> +				      tio->io->bio->bi_bdev->bd_dev, sector);
>  
>  		generic_make_request(clone);
>  	} else if (r < 0 || r == DM_MAPIO_REQUEUE) {
> diff --git a/include/trace/events/block.h b/include/trace/events/block.h
> index d8ce278..b56c65d 100644
> --- a/include/trace/events/block.h
> +++ b/include/trace/events/block.h
> @@ -486,16 +486,16 @@ TRACE_EVENT(block_split,
>  );
>  
>  /**
> - * block_remap - map request for a partition to the raw device
> + * block_bio_remap - map request for a logical device to the raw device
>   * @q: queue holding the operation
>   * @bio: revised operation
>   * @dev: device for the operation
>   * @from: original sector for the operation
>   *
> - * An operation for a partition on a block device has been mapped to the
> + * An operation for a logical device has been mapped to the
>   * raw block device.
>   */
> -TRACE_EVENT(block_remap,
> +TRACE_EVENT(block_bio_remap,
>  
>  	TP_PROTO(struct request_queue *q, struct bio *bio, dev_t dev,
>  		 sector_t from),
> diff --git a/kernel/trace/blktrace.c b/kernel/trace/blktrace.c
> index bc251ed..9f42529 100644
> --- a/kernel/trace/blktrace.c
> +++ b/kernel/trace/blktrace.c
> @@ -889,7 +889,7 @@ static void blk_add_trace_split(void *ignore,
>  }
>  
>  /**
> - * blk_add_trace_remap - Add a trace for a remap operation
> + * blk_add_trace_bio_remap - Add a trace for a bio-remap operation
>   * @ignore:	trace callback data parameter (not used)
>   * @q:		queue the io is for
>   * @bio:	the source bio
> @@ -901,9 +901,9 @@ static void blk_add_trace_split(void *ignore,
>   *     it spans a stripe (or similar). Add a trace for that action.
>   *
>   **/
> -static void blk_add_trace_remap(void *ignore,
> -				struct request_queue *q, struct bio *bio,
> -				dev_t dev, sector_t from)
> +static void blk_add_trace_bio_remap(void *ignore,
> +				    struct request_queue *q, struct bio *bio,
> +				    dev_t dev, sector_t from)
>  {
>  	struct blk_trace *bt = q->blk_trace;
>  	struct blk_io_trace_remap r;
> @@ -1018,7 +1018,7 @@ static void blk_register_tracepoints(void)
>  	WARN_ON(ret);
>  	ret = register_trace_block_split(blk_add_trace_split, NULL);
>  	WARN_ON(ret);
> -	ret = register_trace_block_remap(blk_add_trace_remap, NULL);
> +	ret = register_trace_block_bio_remap(blk_add_trace_bio_remap, NULL);
>  	WARN_ON(ret);
>  	ret = register_trace_block_rq_remap(blk_add_trace_rq_remap, NULL);
>  	WARN_ON(ret);
> @@ -1027,7 +1027,7 @@ static void blk_register_tracepoints(void)
>  static void blk_unregister_tracepoints(void)
>  {
>  	unregister_trace_block_rq_remap(blk_add_trace_rq_remap, NULL);
> -	unregister_trace_block_remap(blk_add_trace_remap, NULL);
> +	unregister_trace_block_bio_remap(blk_add_trace_bio_remap, NULL);
>  	unregister_trace_block_split(blk_add_trace_split, NULL);
>  	unregister_trace_block_unplug_io(blk_add_trace_unplug_io, NULL);
>  	unregister_trace_block_unplug_timer(blk_add_trace_unplug_timer, NULL);

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v2] block: rename trace_block_remap to trace_block_bio_remap
  2010-11-15 20:58     ` Mike Snitzer
@ 2010-11-15 21:34       ` Mike Snitzer
  2010-11-16 11:51         ` Jens Axboe
  0 siblings, 1 reply; 7+ messages in thread
From: Mike Snitzer @ 2010-11-15 21:34 UTC (permalink / raw)
  To: jaxboe
  Cc: device-mapper development, Jun'ichi Nomura,
	Alasdair G Kergon, Li Zefan, linux-kernel

On Mon, Nov 15 2010 at  3:58pm -0500,
Mike Snitzer <snitzer@redhat.com> wrote:

> Hi Jens,
> 
> This may have slipped through while you were traveling?
> 
> Patch is also available here:
> https://patchwork.kernel.org/patch/300552/
> 
> Not sure if this change is concerning on a kABI level?

To be clear: that concern/question was prompted from having taken a
quick glance at lwn's kernel summit "KS2010: ABI status for tracepoints"
coverage: http://lwn.net/Articles/412685/

But in that article it clearly states:
"there are to be no stable tracepoints in drivers or filesystems".

Not sure where that leaves tracepoints for the block layer.  Anyway,
seems tracepoint kABI is likely a concern for the future (not the
immediate future).

So this change would be nice to get in before there is a new tracepoint
kABI-aware sheriff in town.

Mike

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH v2] block: rename trace_block_remap to  trace_block_bio_remap
  2010-11-15 21:34       ` Mike Snitzer
@ 2010-11-16 11:51         ` Jens Axboe
  0 siblings, 0 replies; 7+ messages in thread
From: Jens Axboe @ 2010-11-16 11:51 UTC (permalink / raw)
  To: Mike Snitzer
@@ -889,7 +889,7 @@ static void blk_add_trace_split(void *ignore,
 
 /**
- * blk_add_trace_remap - Add a trace for a remap operation
+ * blk_add_trace_bio_remap - Add a trace for a bio-remap operation
  * @ignore:	trace callback data parameter (not used)
  * @q:		queue the io is for
  Cc: device-mapper development, Jun'ichi Nomura,
	Alasdair G Kergon, Li Zefan, linux-kernel

On 2010-11-15 22:34, Mike Snitzer wrote:
> On Mon, Nov 15 2010 at  3:58pm -0500,
> Mike Snitzer <snitzer@redhat.com> wrote:
> 
>> Hi Jens,
>>
>> This may have slipped through while you were traveling?
>>
>> Patch is also available here:
>> https://patchwork.kernel.org/patch/300552/
>>
>> Not sure if this change is concerning on a kABI level?
> 
> To be clear: that concern/question was prompted from having taken a
> quick glance at lwn's kernel summit "KS2010: ABI status for tracepoints"
> coverage: http://lwn.net/Articles/412685/
> 
> But in that article it clearly states:
> "there are to be no stable tracepoints in drivers or filesystems".
> 
> Not sure where that leaves tracepoints for the block layer.  Anyway,
> seems tracepoint kABI is likely a concern for the future (not the
> immediate future).
> 
> So this change would be nice to get in before there is a new tracepoint
> kABI-aware sheriff in town.

As far as I'm concerned, trace point changes in the block area cannot
break existing blktrace (as in cause malfunction). So this patch is
fine, I'll pick it up for .38.

-- 
Jens Axboe


^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2010-11-16 11:51 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2009-09-18 15:13 [PATCH 2/3] block: Rename trace_block_remap to trace_block_bio_remap Jun'ichi Nomura
2009-09-18 16:13 ` Daniel Walker
2009-09-19 15:30 ` Jun'ichi Nomura
2010-11-03 21:50   ` [PATCH v2] block: rename " Mike Snitzer
2010-11-15 20:58     ` Mike Snitzer
2010-11-15 21:34       ` Mike Snitzer
2010-11-16 11:51         ` Jens Axboe

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).